Documentation
¶
Overview ¶
Package mock_blob is a generated GoMock package.
Index ¶
- type MockBlobServiceClient
- func (m *MockBlobServiceClient) EXPECT() *MockBlobServiceClientMockRecorder
- func (m *MockBlobServiceClient) Get(arg0 context.Context, arg1 *blob.GetRequest, arg2 ...grpc.CallOption) (blob.BlobService_GetClient, error)
- func (m *MockBlobServiceClient) Push(arg0 context.Context, arg1 ...grpc.CallOption) (blob.BlobService_PushClient, error)
- type MockBlobServiceClientMockRecorder
- type MockBlobServiceServer
- type MockBlobServiceServerMockRecorder
- type MockBlobService_GetClient
- func (m *MockBlobService_GetClient) CloseSend() error
- func (m *MockBlobService_GetClient) Context() context.Context
- func (m *MockBlobService_GetClient) EXPECT() *MockBlobService_GetClientMockRecorder
- func (m *MockBlobService_GetClient) Header() (metadata.MD, error)
- func (m *MockBlobService_GetClient) Recv() (*blob.Chunk, error)
- func (m *MockBlobService_GetClient) RecvMsg(arg0 interface{}) error
- func (m *MockBlobService_GetClient) SendMsg(arg0 interface{}) error
- func (m *MockBlobService_GetClient) Trailer() metadata.MD
- type MockBlobService_GetClientMockRecorder
- func (mr *MockBlobService_GetClientMockRecorder) CloseSend() *gomock.Call
- func (mr *MockBlobService_GetClientMockRecorder) Context() *gomock.Call
- func (mr *MockBlobService_GetClientMockRecorder) Header() *gomock.Call
- func (mr *MockBlobService_GetClientMockRecorder) Recv() *gomock.Call
- func (mr *MockBlobService_GetClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_GetClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_GetClientMockRecorder) Trailer() *gomock.Call
- type MockBlobService_GetServer
- func (m *MockBlobService_GetServer) Context() context.Context
- func (m *MockBlobService_GetServer) EXPECT() *MockBlobService_GetServerMockRecorder
- func (m *MockBlobService_GetServer) RecvMsg(arg0 interface{}) error
- func (m *MockBlobService_GetServer) Send(arg0 *blob.Chunk) error
- func (m *MockBlobService_GetServer) SendHeader(arg0 metadata.MD) error
- func (m *MockBlobService_GetServer) SendMsg(arg0 interface{}) error
- func (m *MockBlobService_GetServer) SetHeader(arg0 metadata.MD) error
- func (m *MockBlobService_GetServer) SetTrailer(arg0 metadata.MD)
- type MockBlobService_GetServerMockRecorder
- func (mr *MockBlobService_GetServerMockRecorder) Context() *gomock.Call
- func (mr *MockBlobService_GetServerMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_GetServerMockRecorder) Send(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_GetServerMockRecorder) SendHeader(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_GetServerMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_GetServerMockRecorder) SetHeader(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_GetServerMockRecorder) SetTrailer(arg0 interface{}) *gomock.Call
- type MockBlobService_PushClient
- func (m *MockBlobService_PushClient) CloseAndRecv() (*blob.PushStatus, error)
- func (m *MockBlobService_PushClient) CloseSend() error
- func (m *MockBlobService_PushClient) Context() context.Context
- func (m *MockBlobService_PushClient) EXPECT() *MockBlobService_PushClientMockRecorder
- func (m *MockBlobService_PushClient) Header() (metadata.MD, error)
- func (m *MockBlobService_PushClient) RecvMsg(arg0 interface{}) error
- func (m *MockBlobService_PushClient) Send(arg0 *blob.Chunk) error
- func (m *MockBlobService_PushClient) SendMsg(arg0 interface{}) error
- func (m *MockBlobService_PushClient) Trailer() metadata.MD
- type MockBlobService_PushClientMockRecorder
- func (mr *MockBlobService_PushClientMockRecorder) CloseAndRecv() *gomock.Call
- func (mr *MockBlobService_PushClientMockRecorder) CloseSend() *gomock.Call
- func (mr *MockBlobService_PushClientMockRecorder) Context() *gomock.Call
- func (mr *MockBlobService_PushClientMockRecorder) Header() *gomock.Call
- func (mr *MockBlobService_PushClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushClientMockRecorder) Send(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushClientMockRecorder) Trailer() *gomock.Call
- type MockBlobService_PushServer
- func (m *MockBlobService_PushServer) Context() context.Context
- func (m *MockBlobService_PushServer) EXPECT() *MockBlobService_PushServerMockRecorder
- func (m *MockBlobService_PushServer) Recv() (*blob.Chunk, error)
- func (m *MockBlobService_PushServer) RecvMsg(arg0 interface{}) error
- func (m *MockBlobService_PushServer) SendAndClose(arg0 *blob.PushStatus) error
- func (m *MockBlobService_PushServer) SendHeader(arg0 metadata.MD) error
- func (m *MockBlobService_PushServer) SendMsg(arg0 interface{}) error
- func (m *MockBlobService_PushServer) SetHeader(arg0 metadata.MD) error
- func (m *MockBlobService_PushServer) SetTrailer(arg0 metadata.MD)
- type MockBlobService_PushServerMockRecorder
- func (mr *MockBlobService_PushServerMockRecorder) Context() *gomock.Call
- func (mr *MockBlobService_PushServerMockRecorder) Recv() *gomock.Call
- func (mr *MockBlobService_PushServerMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushServerMockRecorder) SendAndClose(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushServerMockRecorder) SendHeader(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushServerMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushServerMockRecorder) SetHeader(arg0 interface{}) *gomock.Call
- func (mr *MockBlobService_PushServerMockRecorder) SetTrailer(arg0 interface{}) *gomock.Call
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MockBlobServiceClient ¶
type MockBlobServiceClient struct {
// contains filtered or unexported fields
}
MockBlobServiceClient is a mock of BlobServiceClient interface
func NewMockBlobServiceClient ¶
func NewMockBlobServiceClient(ctrl *gomock.Controller) *MockBlobServiceClient
NewMockBlobServiceClient creates a new mock instance
func (*MockBlobServiceClient) EXPECT ¶
func (m *MockBlobServiceClient) EXPECT() *MockBlobServiceClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBlobServiceClient) Get ¶
func (m *MockBlobServiceClient) Get(arg0 context.Context, arg1 *blob.GetRequest, arg2 ...grpc.CallOption) (blob.BlobService_GetClient, error)
Get mocks base method
func (*MockBlobServiceClient) Push ¶
func (m *MockBlobServiceClient) Push(arg0 context.Context, arg1 ...grpc.CallOption) (blob.BlobService_PushClient, error)
Push mocks base method
type MockBlobServiceClientMockRecorder ¶
type MockBlobServiceClientMockRecorder struct {
// contains filtered or unexported fields
}
MockBlobServiceClientMockRecorder is the mock recorder for MockBlobServiceClient
func (*MockBlobServiceClientMockRecorder) Get ¶
func (mr *MockBlobServiceClientMockRecorder) Get(arg0, arg1 interface{}, arg2 ...interface{}) *gomock.Call
Get indicates an expected call of Get
func (*MockBlobServiceClientMockRecorder) Push ¶
func (mr *MockBlobServiceClientMockRecorder) Push(arg0 interface{}, arg1 ...interface{}) *gomock.Call
Push indicates an expected call of Push
type MockBlobServiceServer ¶
type MockBlobServiceServer struct {
// contains filtered or unexported fields
}
MockBlobServiceServer is a mock of BlobServiceServer interface
func NewMockBlobServiceServer ¶
func NewMockBlobServiceServer(ctrl *gomock.Controller) *MockBlobServiceServer
NewMockBlobServiceServer creates a new mock instance
func (*MockBlobServiceServer) EXPECT ¶
func (m *MockBlobServiceServer) EXPECT() *MockBlobServiceServerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBlobServiceServer) Get ¶
func (m *MockBlobServiceServer) Get(arg0 *blob.GetRequest, arg1 blob.BlobService_GetServer) error
Get mocks base method
func (*MockBlobServiceServer) Push ¶
func (m *MockBlobServiceServer) Push(arg0 blob.BlobService_PushServer) error
Push mocks base method
type MockBlobServiceServerMockRecorder ¶
type MockBlobServiceServerMockRecorder struct {
// contains filtered or unexported fields
}
MockBlobServiceServerMockRecorder is the mock recorder for MockBlobServiceServer
func (*MockBlobServiceServerMockRecorder) Get ¶
func (mr *MockBlobServiceServerMockRecorder) Get(arg0, arg1 interface{}) *gomock.Call
Get indicates an expected call of Get
func (*MockBlobServiceServerMockRecorder) Push ¶
func (mr *MockBlobServiceServerMockRecorder) Push(arg0 interface{}) *gomock.Call
Push indicates an expected call of Push
type MockBlobService_GetClient ¶
type MockBlobService_GetClient struct {
// contains filtered or unexported fields
}
MockBlobService_GetClient is a mock of BlobService_GetClient interface
func NewMockBlobService_GetClient ¶
func NewMockBlobService_GetClient(ctrl *gomock.Controller) *MockBlobService_GetClient
NewMockBlobService_GetClient creates a new mock instance
func (*MockBlobService_GetClient) CloseSend ¶
func (m *MockBlobService_GetClient) CloseSend() error
CloseSend mocks base method
func (*MockBlobService_GetClient) Context ¶
func (m *MockBlobService_GetClient) Context() context.Context
Context mocks base method
func (*MockBlobService_GetClient) EXPECT ¶
func (m *MockBlobService_GetClient) EXPECT() *MockBlobService_GetClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBlobService_GetClient) Header ¶
func (m *MockBlobService_GetClient) Header() (metadata.MD, error)
Header mocks base method
func (*MockBlobService_GetClient) Recv ¶
func (m *MockBlobService_GetClient) Recv() (*blob.Chunk, error)
Recv mocks base method
func (*MockBlobService_GetClient) RecvMsg ¶
func (m *MockBlobService_GetClient) RecvMsg(arg0 interface{}) error
RecvMsg mocks base method
func (*MockBlobService_GetClient) SendMsg ¶
func (m *MockBlobService_GetClient) SendMsg(arg0 interface{}) error
SendMsg mocks base method
func (*MockBlobService_GetClient) Trailer ¶
func (m *MockBlobService_GetClient) Trailer() metadata.MD
Trailer mocks base method
type MockBlobService_GetClientMockRecorder ¶
type MockBlobService_GetClientMockRecorder struct {
// contains filtered or unexported fields
}
MockBlobService_GetClientMockRecorder is the mock recorder for MockBlobService_GetClient
func (*MockBlobService_GetClientMockRecorder) CloseSend ¶
func (mr *MockBlobService_GetClientMockRecorder) CloseSend() *gomock.Call
CloseSend indicates an expected call of CloseSend
func (*MockBlobService_GetClientMockRecorder) Context ¶
func (mr *MockBlobService_GetClientMockRecorder) Context() *gomock.Call
Context indicates an expected call of Context
func (*MockBlobService_GetClientMockRecorder) Header ¶
func (mr *MockBlobService_GetClientMockRecorder) Header() *gomock.Call
Header indicates an expected call of Header
func (*MockBlobService_GetClientMockRecorder) Recv ¶
func (mr *MockBlobService_GetClientMockRecorder) Recv() *gomock.Call
Recv indicates an expected call of Recv
func (*MockBlobService_GetClientMockRecorder) RecvMsg ¶
func (mr *MockBlobService_GetClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
RecvMsg indicates an expected call of RecvMsg
func (*MockBlobService_GetClientMockRecorder) SendMsg ¶
func (mr *MockBlobService_GetClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
SendMsg indicates an expected call of SendMsg
func (*MockBlobService_GetClientMockRecorder) Trailer ¶
func (mr *MockBlobService_GetClientMockRecorder) Trailer() *gomock.Call
Trailer indicates an expected call of Trailer
type MockBlobService_GetServer ¶
type MockBlobService_GetServer struct {
// contains filtered or unexported fields
}
MockBlobService_GetServer is a mock of BlobService_GetServer interface
func NewMockBlobService_GetServer ¶
func NewMockBlobService_GetServer(ctrl *gomock.Controller) *MockBlobService_GetServer
NewMockBlobService_GetServer creates a new mock instance
func (*MockBlobService_GetServer) Context ¶
func (m *MockBlobService_GetServer) Context() context.Context
Context mocks base method
func (*MockBlobService_GetServer) EXPECT ¶
func (m *MockBlobService_GetServer) EXPECT() *MockBlobService_GetServerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBlobService_GetServer) RecvMsg ¶
func (m *MockBlobService_GetServer) RecvMsg(arg0 interface{}) error
RecvMsg mocks base method
func (*MockBlobService_GetServer) Send ¶
func (m *MockBlobService_GetServer) Send(arg0 *blob.Chunk) error
Send mocks base method
func (*MockBlobService_GetServer) SendHeader ¶
func (m *MockBlobService_GetServer) SendHeader(arg0 metadata.MD) error
SendHeader mocks base method
func (*MockBlobService_GetServer) SendMsg ¶
func (m *MockBlobService_GetServer) SendMsg(arg0 interface{}) error
SendMsg mocks base method
func (*MockBlobService_GetServer) SetHeader ¶
func (m *MockBlobService_GetServer) SetHeader(arg0 metadata.MD) error
SetHeader mocks base method
func (*MockBlobService_GetServer) SetTrailer ¶
func (m *MockBlobService_GetServer) SetTrailer(arg0 metadata.MD)
SetTrailer mocks base method
type MockBlobService_GetServerMockRecorder ¶
type MockBlobService_GetServerMockRecorder struct {
// contains filtered or unexported fields
}
MockBlobService_GetServerMockRecorder is the mock recorder for MockBlobService_GetServer
func (*MockBlobService_GetServerMockRecorder) Context ¶
func (mr *MockBlobService_GetServerMockRecorder) Context() *gomock.Call
Context indicates an expected call of Context
func (*MockBlobService_GetServerMockRecorder) RecvMsg ¶
func (mr *MockBlobService_GetServerMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
RecvMsg indicates an expected call of RecvMsg
func (*MockBlobService_GetServerMockRecorder) Send ¶
func (mr *MockBlobService_GetServerMockRecorder) Send(arg0 interface{}) *gomock.Call
Send indicates an expected call of Send
func (*MockBlobService_GetServerMockRecorder) SendHeader ¶
func (mr *MockBlobService_GetServerMockRecorder) SendHeader(arg0 interface{}) *gomock.Call
SendHeader indicates an expected call of SendHeader
func (*MockBlobService_GetServerMockRecorder) SendMsg ¶
func (mr *MockBlobService_GetServerMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
SendMsg indicates an expected call of SendMsg
func (*MockBlobService_GetServerMockRecorder) SetHeader ¶
func (mr *MockBlobService_GetServerMockRecorder) SetHeader(arg0 interface{}) *gomock.Call
SetHeader indicates an expected call of SetHeader
func (*MockBlobService_GetServerMockRecorder) SetTrailer ¶
func (mr *MockBlobService_GetServerMockRecorder) SetTrailer(arg0 interface{}) *gomock.Call
SetTrailer indicates an expected call of SetTrailer
type MockBlobService_PushClient ¶
type MockBlobService_PushClient struct {
// contains filtered or unexported fields
}
MockBlobService_PushClient is a mock of BlobService_PushClient interface
func NewMockBlobService_PushClient ¶
func NewMockBlobService_PushClient(ctrl *gomock.Controller) *MockBlobService_PushClient
NewMockBlobService_PushClient creates a new mock instance
func (*MockBlobService_PushClient) CloseAndRecv ¶
func (m *MockBlobService_PushClient) CloseAndRecv() (*blob.PushStatus, error)
CloseAndRecv mocks base method
func (*MockBlobService_PushClient) CloseSend ¶
func (m *MockBlobService_PushClient) CloseSend() error
CloseSend mocks base method
func (*MockBlobService_PushClient) Context ¶
func (m *MockBlobService_PushClient) Context() context.Context
Context mocks base method
func (*MockBlobService_PushClient) EXPECT ¶
func (m *MockBlobService_PushClient) EXPECT() *MockBlobService_PushClientMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBlobService_PushClient) Header ¶
func (m *MockBlobService_PushClient) Header() (metadata.MD, error)
Header mocks base method
func (*MockBlobService_PushClient) RecvMsg ¶
func (m *MockBlobService_PushClient) RecvMsg(arg0 interface{}) error
RecvMsg mocks base method
func (*MockBlobService_PushClient) Send ¶
func (m *MockBlobService_PushClient) Send(arg0 *blob.Chunk) error
Send mocks base method
func (*MockBlobService_PushClient) SendMsg ¶
func (m *MockBlobService_PushClient) SendMsg(arg0 interface{}) error
SendMsg mocks base method
func (*MockBlobService_PushClient) Trailer ¶
func (m *MockBlobService_PushClient) Trailer() metadata.MD
Trailer mocks base method
type MockBlobService_PushClientMockRecorder ¶
type MockBlobService_PushClientMockRecorder struct {
// contains filtered or unexported fields
}
MockBlobService_PushClientMockRecorder is the mock recorder for MockBlobService_PushClient
func (*MockBlobService_PushClientMockRecorder) CloseAndRecv ¶
func (mr *MockBlobService_PushClientMockRecorder) CloseAndRecv() *gomock.Call
CloseAndRecv indicates an expected call of CloseAndRecv
func (*MockBlobService_PushClientMockRecorder) CloseSend ¶
func (mr *MockBlobService_PushClientMockRecorder) CloseSend() *gomock.Call
CloseSend indicates an expected call of CloseSend
func (*MockBlobService_PushClientMockRecorder) Context ¶
func (mr *MockBlobService_PushClientMockRecorder) Context() *gomock.Call
Context indicates an expected call of Context
func (*MockBlobService_PushClientMockRecorder) Header ¶
func (mr *MockBlobService_PushClientMockRecorder) Header() *gomock.Call
Header indicates an expected call of Header
func (*MockBlobService_PushClientMockRecorder) RecvMsg ¶
func (mr *MockBlobService_PushClientMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
RecvMsg indicates an expected call of RecvMsg
func (*MockBlobService_PushClientMockRecorder) Send ¶
func (mr *MockBlobService_PushClientMockRecorder) Send(arg0 interface{}) *gomock.Call
Send indicates an expected call of Send
func (*MockBlobService_PushClientMockRecorder) SendMsg ¶
func (mr *MockBlobService_PushClientMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
SendMsg indicates an expected call of SendMsg
func (*MockBlobService_PushClientMockRecorder) Trailer ¶
func (mr *MockBlobService_PushClientMockRecorder) Trailer() *gomock.Call
Trailer indicates an expected call of Trailer
type MockBlobService_PushServer ¶
type MockBlobService_PushServer struct {
// contains filtered or unexported fields
}
MockBlobService_PushServer is a mock of BlobService_PushServer interface
func NewMockBlobService_PushServer ¶
func NewMockBlobService_PushServer(ctrl *gomock.Controller) *MockBlobService_PushServer
NewMockBlobService_PushServer creates a new mock instance
func (*MockBlobService_PushServer) Context ¶
func (m *MockBlobService_PushServer) Context() context.Context
Context mocks base method
func (*MockBlobService_PushServer) EXPECT ¶
func (m *MockBlobService_PushServer) EXPECT() *MockBlobService_PushServerMockRecorder
EXPECT returns an object that allows the caller to indicate expected use
func (*MockBlobService_PushServer) Recv ¶
func (m *MockBlobService_PushServer) Recv() (*blob.Chunk, error)
Recv mocks base method
func (*MockBlobService_PushServer) RecvMsg ¶
func (m *MockBlobService_PushServer) RecvMsg(arg0 interface{}) error
RecvMsg mocks base method
func (*MockBlobService_PushServer) SendAndClose ¶
func (m *MockBlobService_PushServer) SendAndClose(arg0 *blob.PushStatus) error
SendAndClose mocks base method
func (*MockBlobService_PushServer) SendHeader ¶
func (m *MockBlobService_PushServer) SendHeader(arg0 metadata.MD) error
SendHeader mocks base method
func (*MockBlobService_PushServer) SendMsg ¶
func (m *MockBlobService_PushServer) SendMsg(arg0 interface{}) error
SendMsg mocks base method
func (*MockBlobService_PushServer) SetHeader ¶
func (m *MockBlobService_PushServer) SetHeader(arg0 metadata.MD) error
SetHeader mocks base method
func (*MockBlobService_PushServer) SetTrailer ¶
func (m *MockBlobService_PushServer) SetTrailer(arg0 metadata.MD)
SetTrailer mocks base method
type MockBlobService_PushServerMockRecorder ¶
type MockBlobService_PushServerMockRecorder struct {
// contains filtered or unexported fields
}
MockBlobService_PushServerMockRecorder is the mock recorder for MockBlobService_PushServer
func (*MockBlobService_PushServerMockRecorder) Context ¶
func (mr *MockBlobService_PushServerMockRecorder) Context() *gomock.Call
Context indicates an expected call of Context
func (*MockBlobService_PushServerMockRecorder) Recv ¶
func (mr *MockBlobService_PushServerMockRecorder) Recv() *gomock.Call
Recv indicates an expected call of Recv
func (*MockBlobService_PushServerMockRecorder) RecvMsg ¶
func (mr *MockBlobService_PushServerMockRecorder) RecvMsg(arg0 interface{}) *gomock.Call
RecvMsg indicates an expected call of RecvMsg
func (*MockBlobService_PushServerMockRecorder) SendAndClose ¶
func (mr *MockBlobService_PushServerMockRecorder) SendAndClose(arg0 interface{}) *gomock.Call
SendAndClose indicates an expected call of SendAndClose
func (*MockBlobService_PushServerMockRecorder) SendHeader ¶
func (mr *MockBlobService_PushServerMockRecorder) SendHeader(arg0 interface{}) *gomock.Call
SendHeader indicates an expected call of SendHeader
func (*MockBlobService_PushServerMockRecorder) SendMsg ¶
func (mr *MockBlobService_PushServerMockRecorder) SendMsg(arg0 interface{}) *gomock.Call
SendMsg indicates an expected call of SendMsg
func (*MockBlobService_PushServerMockRecorder) SetHeader ¶
func (mr *MockBlobService_PushServerMockRecorder) SetHeader(arg0 interface{}) *gomock.Call
SetHeader indicates an expected call of SetHeader
func (*MockBlobService_PushServerMockRecorder) SetTrailer ¶
func (mr *MockBlobService_PushServerMockRecorder) SetTrailer(arg0 interface{}) *gomock.Call
SetTrailer indicates an expected call of SetTrailer